# pytest-tst

Small pytest plugin that customizes options, output and exit code
to make it run in a compatible way with
[tst](github.com/daltonserey/tst).

## how to install

```
pip3 install --user pytest-tst
```

## how to use

```
pytest --tst
```
